#include <libxml/parser.h>
#include "misc.h"
#include "config.h"
#include "conversion.h"

void XMLSwitch (xmlNodePtr node);
void XMLParse (xmlNodePtr node);
void write_header (void);

FILE *book;

/* Parse an XML node */
void XMLParse (xmlNodePtr node)
{
        char *value = (char *) xmlNodeGetContent (node);
	value+=4;

	trim_str (value);

	if (!xmlStrcmp (node->name, (const xmlChar *)"bookmark"))
		fprintf (book, "<LI><a href=\"%s\">%s</a>\n", xmlGetProp (node, "href"), value);
	
	XMLSwitch (node);
}

/* ... */
void XMLSwitch (xmlNodePtr node)
{
	if (node->xmlChildrenNode)
		XMLParse (node->xmlChildrenNode);
	else
		if (node->next)
			XMLParse (node->next);
		else
			if (node->parent->next)
				XMLParse (node->parent->next);
			else
				return;
}

/* Write the file header */
void write_header (void)
{
	fputs ("<head>\n<META http-equiv=\"content-type\" content=\"text/html;charset=iso-8859-1\">\n<title>Bookmark file</title>\n</head>\n\n<p>\n<ol>\n", book);
}

/* Convert Konqueror bookmarks to lynx bookmarks */
int konq2lynx (void)
{
	xmlDocPtr tree;
	xmlNodePtr root;

	tree = xmlParseFile (KONQ);
	if (tree == NULL)
		Error ("Cannot open Konqueror bookmark file.", 1);
	root = xmlDocGetRootElement (tree);
	book = fopen (LYNX, "w");
	write_header();
	XMLParse (root);
	fclose (book);
	xmlFreeDoc (tree);	
	return 0;
}
